### Description
A clear and concise description of how the PR affects the code. If applicable, refer
the related issue or issues.

**PR type**
Select all the labels that apply to this PR.

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code refactoring
- [ ] Performance improvement
- [ ] Test update
- [ ] Build/CI configuration change
- [ ] Other (please describe):

### Key modifications and changes
A clear and concise list of changes introduced by the PR.

### Affected components
A pointer to the component affected by the PR (juturna core library, a built-in node,
a plugin node).

### Additional context
Add any other context about the PR here
